gromacs.formats – Accessing various files — GromacsWrapper 0.5.0-dev documentation

# `gromacs.formats` – Accessing various files

This module contains classes that represent data files on disk. Typically one creates an instance and

- reads from a file using a `read()` method, or
- populates the instance (in the simplest case with a `set()` method) and the uses the `write()` method to write the data to disk in the appropriate format.

For function data there typically also exists a `plot()` method which produces a graph (using matplotlib).

The module defines some classes that are used in other modules; they do not make use of `gromacs.tools` or `gromacs.cbook` and can be safely imported at any time.

Contents

- Simple xmgrace XVG file format
- Gromacs XPM file format
- Gromacs parameter MDP file format
- Gromacs NDX index file format
- Gromacs topology file (ITP) parser
- Gromacs Preprocessed Topology (top) Parser
- Preprocessor in Python
- `gromacs.fileformats.convert` — converting entries of tables